@@ -10,26 +10,29 @@ def get_parser():
     parser = argparse.ArgumentParser(description=__doc__)
 
     # optionals
-    parser.add_argument('-v', '--verbose', action='store_true', default=False,
-            help='show verbose output')
+    parser.add_argument(
+        '-v', '--verbose', action='store_true', default=False,
+        help='show verbose output')
 
     # positionals
-    parser.add_argument('method', type=str,
-            help='HTTP method to use (OPTIONS, GET, HEAD, POST, PUT, DELETE, '
-                 'TRACE, CONNECT)')
-    parser.add_argument('url', type=str,
-            help='URL to work with')
-    parser.add_argument('body', nargs='?',
-            help='Request body')
-    parser.add_argument('headers', nargs=argparse.REMAINDER, type=headers,
-            help='Additional request headers (keyword=value)')
+    parser.add_argument(
+        'method', type=str,
+        help='HTTP method to use (OPTIONS, GET, HEAD, POST, PUT, DELETE, '
+             'TRACE, CONNECT)')
+    parser.add_argument(
+        'url', type=str, help='URL to work with')
+    parser.add_argument(
+        'body', nargs='?', help='Request body')
+    parser.add_argument(
+        'headers', nargs=argparse.REMAINDER, type=headers,
+        help='Additional request headers (keyword=value)')
 
     return parser
 
 
 def headers(string):
     msg = ('must be formatted as optional keyword arguments, '
-            'e.g. --content-type=application/json')
+           'e.g. --content-type=application/json')
 
     try:
         header, value = string.split('=', 1)
@@ -44,5 +47,6 @@ def headers(string):
     # normalize header names
     return header[2:].title(), value
 
+
 def parse_args(parser):
     return parser.parse_args()
